searchData={"items":[{"type":"module","title":"SqlFmt","doc":"This library provides an Elixir wrapper around the Rust\n[sqlformat](https://github.com/shssoichiro/sqlformat-rs) library. This allows you\nto efficiently format and pretty print SQL queries.","ref":"SqlFmt.html"},{"type":"function","title":"SqlFmt.format_query/2","doc":"This function takes a query as a string along with optional formatting\nsettings and returns the formatted query.\n\nFor formatting settings look at the `SqlFmt.FormatOptions` module docs.","ref":"SqlFmt.html#format_query/2"},{"type":"function","title":"SqlFmt.format_query_with_params/3","doc":"This function takes a query as a string along with its parameters as a list of strings\nand optional formatting settings and returns the formatted query. As a note, when using this\nfunction all of the element in `query_params` must be strings and they all must be\nextrapolated out to their appropriate SQL values. For example query params of `[\"my_id\"]`\nshould be `[\"'my_id'\"]` so that it is valid SQL when the parameter substitution takes place.\n\nFor formatting settings look at the `SqlFmt.FormatOptions` module docs.","ref":"SqlFmt.html#format_query_with_params/3"},{"type":"module","title":"SqlFmt.FormatOptions","doc":"These options are used to control how the SQL statement is formatted. The\navailable formatting options are:\n\n* `:indent` – Specifies how many spaces are used for indents\n  Defaults to `2`.\n\n* `:uppercase` – Configures whether SQL reserved words are capitalized.\n  Defaults to `true`.\n\n* `:lines_between_queries` – Specifies how many line breaks should be\n  present after a query.\n  Defaults to `1`.\n\n* `:ignore_case_convert` – Configures whether certain strings should\n  not be case converted.\n  Defaults to `[]`.","ref":"SqlFmt.FormatOptions.html"},{"type":"function","title":"SqlFmt.FormatOptions.new/1","doc":"Create an instance of the `FormatOptions` struct.","ref":"SqlFmt.FormatOptions.html#new/1"},{"type":"type","title":"SqlFmt.FormatOptions.t/0","doc":"The available formatting options.","ref":"SqlFmt.FormatOptions.html#t:t/0"},{"type":"extras","title":"README","doc":"Format and pretty print SQL queries\n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n\n# Contents\n\n- [Installation](#installation)\n- [Example Output](#example-output)\n- [Supporting SqlFmt](#supporting-sqlfmt)\n- [Attribution](#attribution)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"[Available in Hex](https://hex.pm/packages/sql_fmt), the package can be installed by adding `sql_fmt` to your list of\ndependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sql_fmt, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/sql_fmt](https://hexdocs.pm/sql_fmt).","ref":"readme.html#installation"},{"type":"extras","title":"Example Output - README","doc":"After setting up SqlFmt in your application you can use the SqlFmt functions in order to format queries. Here are a\ncouple examples of queries with having parameters inline and with passing in the parameters separately:\n\n```elixir\niex(1)> {:ok, formatted_sql} = SqlFmt.format_query(\"select * from businesses where id in ('c6f5c5f1-a1fc-4c9a-91f7-6aa40f1e233d', 'f339d4ce-96b6-4440-a541-28a0fb611139');\")\n{:ok, \"SELECT\\n  *\\nFROM\\n  businesses\\nWHERE\\n  id IN (\\n    'c6f5c5f1-a1fc-4c9a-91f7-6aa40f1e233d',\\n    'f339d4ce-96b6-4440-a541-28a0fb611139'\\n  );\"}\n\niex(2)> IO.puts(formatted_sql)\nSELECT\n  *\nFROM\n  businesses\nWHERE\n  id IN (\n    'c6f5c5f1-a1fc-4c9a-91f7-6aa40f1e233d',\n    'f339d4ce-96b6-4440-a541-28a0fb611139'\n  );\n:ok\n```\n\n```elixir\niex(1)> {:ok, formatted_sql} = SqlFmt.format_query_with_params(\"select * from help where help.\\\"col\\\" in $1;\", [\"'asdf'\"])\n{:ok, \"SELECT\\n  *\\nFROM\\n  help\\nWHERE\\n  help.\\\"col\\\" IN 'asdf';\"}\n\niex(2)> IO.puts(formatted_sql)\nSELECT\n  *\nFROM\n  help\nWHERE\n  help.\"col\" IN 'asdf';\n:ok\n```\n\nBe sure to checkout the HexDocs as you can also provide formatting options to the functions to tailor the output to your\nliking.","ref":"readme.html#example-output"},{"type":"extras","title":"Supporting SqlFmt - README","doc":"If you rely on this library help you debug your Ecto/SQL queries, it would much appreciated if you can give back\nto the project in order to help ensure its continued development.\n\nCheckout my [GitHub Sponsorship page](https://github.com/sponsors/akoutmos) if you want to help out!","ref":"readme.html#supporting-sqlfmt"},{"type":"extras","title":"Gold Sponsors - README","doc":"","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Attribution - README","doc":"- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/).\n- The SqlFmt library leans on the Rust library [sqlformat-rs](https://github.com/shssoichiro/sqlformat-rs) for SQL\n  statement formatting.","ref":"readme.html#attribution"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}